# Spare Stunden mit diesem SEO Tool! Neues Feature im Tool-Stack: SERP-Overlap-Analyse in Visibly AI

> **Source:** [Antonio Blago](https://www.youtube.com/channel/UCoIBDdswc5VViHYPTKd0HwA) | **Duration:** 05:39 | **Published:** 20260201
> **URL:** [https://www.youtube.com/watch?v=QhruXhHE9ts](https://www.youtube.com/watch?v=QhruXhHE9ts)
> **Views:** 23

In diesem Video stelle ich dir mein neuestes Feature vor: die SERP-Overlap-Bulk Analyse in Visibly AI.

Du erfährst, wie du viele ähnliche Keywords gleichzeitig analysierst und datenbasiert entscheidest, ob sie auf einer starken Seite gebündelt oder auf mehrere Seiten verteilt werden sollten.

Damit...

---

## Table of Contents

- [<Untitled Chapter 1>](#untitled-chapter-1-00:00-00:01)
- [Einführung: SERP-Overlap-Analyse erklärt](#einfhrung-serp-overlap-analyse-erklrt-00:01-00:40)
- [SEO-Kernfrage: Eine Seite oder mehrere?](#seo-kernfrage-eine-seite-oder-mehrere-00:40-01:11)
- [Keyword-Setup & Premium-Feature](#keyword-setup-premium-feature-01:11-02:18)
- [Praxisbeispiel: Keyword-Cluster im Einsatz](#praxisbeispiel-keyword-cluster-im-einsatz-02:18-04:25)
- [Deep Dive: Seitentypen, Wettbewerber & Exporte](#deep-dive-seitentypen-wettbewerber-exporte-04:25-05:39)

---

### <Untitled Chapter 1> (00:00 - 00:01)


---

### Einführung: SERP-Overlap-Analyse erklärt (00:01 - 00:40)

Ja, herzlich willkommen. Hier zeige ich euch mein neuestes Feature und zwar die Serp Overlap Analyse. Also, man kann hier balk auch mehrere Keywords im Serb Overlap analysieren im Tool Visibly AI. Ähm, hier habe ich ja schon ganz andere Tools auch noch mal, die werde ich auch noch mal vorstellen. Ähm, genau. Und hier kannst du wie gesagt mehrere Keywords auch in dem Sinne analysieren, also im Serb Overlap prüfen, ob ob es wichtig ist für die einzelnen Keywords auch noch mal dezidierte Seiten anzulegen, ne? Also, wenn du viele Keywords hast, ähm 50 bis

---

### SEO-Kernfrage: Eine Seite oder mehrere? (00:40 - 01:11)

dezidierte Seiten anzulegen, ne? Also, wenn du viele Keywords hast, ähm 50 bis 100 Keywords, da unterschiedliche ähm ja, ob du da jedes Mal prüfen musst bei Google, welche Seitentyp etc. und wie sehen die Suchergebnisse aus und brauchen die dezitierte Seiten. Das ist für SEO immer eine wichtige Aufgabe, aber natürlich auch sehr zeitensiv und dafür habe ich ein Tool erstellt und da kannst du einfach hier die Keywords dann eingeben. kannst du entweder ähm ja, Keyword äh 2 sozusagen und dann ähm

---

### Keyword-Setup & Premium-Feature (01:11 - 02:18)

entweder ähm ja, Keyword äh 2 sozusagen und dann ähm brauchst du immer äh kannst du hier bis zu 100 Keywords eingeben und dann äh auch die äh das Land sozusagen und die Sprache. Ähm genau. Und dann steht hier auch quasi der Credit Preis, also ist nur für die äh Premiunnutzer möglich dieses Feature, weil es natürlich auch im Hintergrund viele Abfragen. äh macht. Vielleicht mache ich es auch mal für zwei oder ähm fünf oder sechs Keywords maximal kostenfrei. Ähm im Hintergrund ruft es natürlich ähm Data V SEO ähm auf und dann ähm prüft es den äh Ser Overlap. Ähm genau. Und hier kann man z.B. eine Beispielanalyse sehen. Ähm habe ich jetzt mal für äh 12 Beispiel Keywords gemacht. Ähm für Laufschuhe Herrn Frühling, äh Herrenlaufschuhe Frühling, Laufschuhe für Herren Frühjahr, ne? Also so viele Keywords, ne, die in so einem Kluster vorkommen können und der prüft dann hier haben die Such Suchvolungen, diese Keywords, ne? Ähm und müssen die halt in

---

### Praxisbeispiel: Keyword-Cluster im Einsatz (02:18 - 04:25)

haben die Such Suchvolungen, diese Keywords, ne? Ähm und müssen die halt in eine separate Seite jeweils oder können die alle auch auf einer Seite vorkommen? Und ähm dann hat man hier z.B. die Empfehlung, das sind diese ganzen Keywords ergeben zwei Klaster. Ähm und zwar halt Laufschuhe Herren leicht äh gehört zu atmungsaktive Laufschuhe Herren Frühling oder Laufschuhe herren atmungsaktiv, ne? Also die könnte man alle auf einer Seite spielen, weil das Serve Overlap hier recht ähnlich ist. Ähm und das wird eine Collection oder eine Kategorieseite empfohlen. Äh und dann hat man hier noch das Klaster Laufschuheen Frühling, wo diese ganzen Keywords drin vorkommen können. Und ähm hier sieht er auch in dem Sinne, welche Keywords gar kein Suchvolumen haben. Insofern entfelt er da auch noch mal nachzuprüfen, ob die Keywords dann auch wirklich wichtig sind. Ähm, genau. Und dann kann man auch noch mal äh Deep machen, ähm welche äh ja äh Keywordpare es gibt sozusagen, welche in hohen äh Ser Overlap haben, welche Domains äh da ähnlich sind. Ähm, da kann man hier auch noch mal reinschauen. Ähm, genau. Und äh in der Keyword Kategorisierung sieht man dann auch noch mal die Keywords mit dem Suchvolumen von Datav SEO, dann empfohlener Seitentyp, die Seitentypen ähm von den Seiten, die auf Google ranken. Ähm, genau. Und dann hat man auch noch die Topbewerber, also die Wettbewerber, die in allen Keywords in dem Sinne vorkommen. Ähm, genau. Amazon ist halt sehr stark sichtbar. Salando Running, Running Point, Otto etc. Genau. Und dann hat man hier auch noch mal Serb Overlap Matrix, also äh welche äh Rankings das Unternehmen hat in dem jeweiligen äh Serb Abrufen, also welche Positionen aktuell da sind. Ähm ist auch

---

### Deep Dive: Seitentypen, Wettbewerber & Exporte (04:25 - 05:39)

jeweiligen äh Serb Abrufen, also welche Positionen aktuell da sind. Ähm ist auch immer ganz praktisch zu sehen für diese ganzen Keywords und auch ein Feature, was ich ganz cool finde, zu sagen, okay, ähm noch mal zu den jeweiligen Keywords, andere Keyword Ideen zu bekommen, ne? Also äh Ke zu den Suchvolumen gibt, also z.B. äh zu Laufschuhen Herren leicht empfiehlt er mir dann noch mal leichte Schuhen Herren Deichmann ähm oder extrem leichte Schuhen Herrn äh 140 Suchvolumen CPC ähm genau. Und diese ganzen Kees kannst du auch noch mal exportieren. Ähm genau oder auch noch mal äh Ser Overlap prüfen lassen. Du kannst dir auch die Keywords ähm noch mal kopieren, ne? äh brauchst die dann nicht äh ja irgendwo zu speichern. Du kannst auch noch mal als Markdown runterladen mit dem Prompt äh um das in der AI dann design zu erstellen. Kannst du das Export äh mit CSV machen oder du kannst auch im SEO Copilot dann noch mal damit weiterarbeiten und eine Art URL Mapping erstellen. Genau, auf Basis der Analyse. Also ähm genau schreib mir gerne mal, was du von diesem Feature denkst und ob du das gerne nutzen würdest. Mach's gut. Co?

---


*Transcript source: youtube_auto_generated*
*Confidence: 80%*